@@ -1,7 +1,7 @@
 package Getopt::Long::Subcommand;
 
-our $DATE = '2015-02-11'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-02-12'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -250,7 +250,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.01 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-02-11.
+This document describes version 0.02 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-02-12.
 
 =head1 SYNOPSIS
 
@@ -258,6 +258,7 @@ This document describes version 0.01 of Getopt::Long::Subcommand (from Perl dist
 
  my %opts;
  my $res = GetOptions(
+
      summary => 'Summary about your program ...',
 
      # common options recognized by all subcommands
@@ -303,6 +304,16 @@ This document describes version 0.01 of Getopt::Long::Subcommand (from Perl dist
              },
          },
      },
+
+     # tell how to complete option value and arguments. see
+     # Getopt::Long::Complete for more details, the arguments are the same
+     # except there is an additional 'subcommand' that gives the subcommand
+     # name.
+     completion => sub {
+         my %args = @_;
+         ...
+     },
+
  );
  die "GetOptions failed!\n" unless $res->{success};
  say "Running subcommand $res->{subcommand} ...";
@@ -334,26 +345,21 @@ B<STATUS: EARLY RELEASE, EXPERIMENTAL.>
 
 This module extends L<Getopt::Long> with subcommands and tab completion ability.
 
-How parsing works: we first try to gather all options specifications. First is
-the common options. If there are subcommands, subcommand name is then first
-stripped from first element of C<@ARGV>. We then gather subcommand options. If
-subcommand also has nested subcommand, the process is repeated. Finally, we
-merged all options specifications into a single one and hand it off to
-L<Getopt::Long>.
-
-then retrieved from the first element of C<@ARGV>. After that, subcommand
-options will be parsed from C<@ARGV>. If subcommand has a nested subcommand, the
-process is repeated.
+How parsing works: First we call C<Getopt::Long::GetOptions> with the top-level
+options, passing through unknown options if we have subcommands. Then,
+subcommand name is taken from the first argument. If subcommand has options, the
+process is repeated. So C<Getopt::Long::GetOptions> is called once at every
+level.
 
 Completion: Scripts using this module can complete themselves. Just put your
 script somewhere in your C<PATH> and run something like this in your bash shell:
 C<complete -C script-name script-name>. See also L<shcompgen> to manage
 completion scripts for multiple applications easily.
 
-How completion works: Eenvironment variable C<COMP_LINE> or C<COMMAND_LINE> (for
+How completion works: Environment variable C<COMP_LINE> or C<COMMAND_LINE> (for
 tcsh) is first checked. If it exists, we are in completion mode and C<@ARGV> is
-parsed/formed from it. We then gather and merge all options specifications just
-like normal parsing. Finally we hand it off to L<Complete::Getopt::Long>.
+parsed/formed from it. We then perform parsing to get subcommand names. Finally
+we hand it off to L<Complete::Getopt::Long>.
 
 =head1 FUNCTIONS
 
@@ -367,8 +373,8 @@ command-line options parsing will be done using L<Getopt::Long>.
 
 Return hash structure, with these keys: C<success> (bool, false if parsing
 options failed e.g. unknown option/subcommand, illegal option value, etc),
-C<subcommand> (str, subcommand name, if there is any; if there are nested
-subcommands then it will be a path separated name, e.g. C<sub1/subsub1>).
+C<subcommand> (array of str, subcommand name, if there is any; nested
+subcommands will be listed in order, e.g. C<< ["sub1", "subsub1"] >>).
 
 Arguments:
 
